pub trait MaybePosition {
// Required method
fn position(&mut self) -> Option<u64>;
}Expand description
Helper trait to allow users to possibly get a location in the stream, where
types that cannot report this information fall back to reporting None.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".